Struct spandex::document::Document[][src]

pub struct Document { /* fields omitted */ }
This struct contains the pdf document.

Implementations

Creates a new pdf document from its name and its size in pt.

Returns a reference to the inner pdf document.

Returns a mutable reference to the inner pdf document.

Renders an AST to the document.

Writes content on the document.

Writes a paragraph on the document.

Writes a line in the document.

Goes to the beginning of the next line.

Creates a new page and append it to the document.

Saves the document into a file.