Struct spandex::document::Document [−][src]
pub struct Document { /* fields omitted */ }Expand description
This struct contains the pdf document.
Implementations
Creates a new pdf document from its name and its size in pt.
Returns a mutable reference to the inner pdf document.
Renders an AST to the document.
Writes content on the document.
pub fn write_paragraph<J: Justifier>(
&mut self,
paragraph: &Ast,
font_config: &FontConfig<'_>,
size: Pt,
dict: &Standard
)
pub fn write_paragraph<J: Justifier>(
&mut self,
paragraph: &Ast,
font_config: &FontConfig<'_>,
size: Pt,
dict: &Standard
)
Writes a paragraph on the document.
Writes a line in the document.